@@ -25,6 +25,7 @@ from pyverbs.qp import QPCap, QPInitAttrEx, QPAttr
 import pyverbs.providers.mlx5.mlx5_enums as dve
 from pyverbs.addr import AHAttr, GlobalRoute
 from pyverbs.cq import CqInitAttrEx
+from pyverbs.device import FdArr
 import pyverbs.mem_alloc as mem
 import pyverbs.dma_util as dma
 import pyverbs.device as d
@@ -1044,3 +1045,53 @@ class Mlx5RcResources(RCResources):
             if ex.error_code == errno.EOPNOTSUPP:
                 raise unittest.SkipTest('Create Mlx5DV CQ is not supported')
             raise ex
+
+
+def create_privileged_context(agr_obj):
+    """
+    Creates a mlx5 privileged context.
+    :param agr_obj: Aggregation object which contains all resources necessary.
+    """
+    fds_paths = ['/dev/infiniband/mlx5_perm_ctrl_local',
+                     '/dev/infiniband/mlx5_perm_ctrl_other_vhca']
+    open_fds = []
+    try:
+        for file_path in fds_paths:
+            fd = open(file_path, 'rb')
+            open_fds.append(fd)
+        agr_obj.fds = FdArr(arr=[fd.fileno() for fd in open_fds], count=len(open_fds))
+        attr = Mlx5DVContextAttr(flags=dve.MLX5DV_CONTEXT_FLAGS_DEVX,
+                                    comp_mask=dve.MLX5DV_CONTEXT_ATTR_MASK_FD_ARRAY,
+                                    fds=agr_obj.fds)
+        agr_obj.ctx = Mlx5Context(attr, agr_obj.dev_name)
+        for fd in open_fds: fd.close()
+    except FileNotFoundError:
+        for fd in open_fds: fd.close()
+        raise unittest.SkipTest(f'FDs file not found')
+    except PyverbsUserError as ex:
+        for fd in open_fds: fd.close()
+        raise unittest.SkipTest(f'Could not open mlx5 context ({ex})')
+    except PyverbsRDMAError as ex:
+        for fd in open_fds: fd.close()
+        raise unittest.SkipTest(f'Opening mlx5 DevX context is not supported ({ex})')
+
+
+class Mlx5PrivilegedRC(Mlx5RcResources):
+    def __init__(self, dev_name, ib_port, gid_index, msg_size=1024, **kwargs):
+        """
+        Initialize mlx5 DV privileged context resources based on Mlx5RcResources.
+        :param dev_name: Device name to be used
+        :param ib_port: IB port of the device to use
+        :param gid_index: Which GID index to use
+        :param msg_size: The resource msg size
+        :param kwargs: General arguments
+        """
+        self.open_fds = []
+        super().__init__(dev_name, ib_port, gid_index, msg_size=msg_size, **kwargs)
+
+    def create_context(self):
+        return create_privileged_context(self)
+
+    def close_fds(self):
+        for open_fd in self.open_fds:
+                open_fd.close()
